@@ -76,23 +76,6 @@ def columnStr(*cols):
     return "\n".join(generateStrings(*cols))
 
 
-def columnWrite(*cols):
-    """
-    Display data by columns
-
-    Parameters:
-    cols     list(tuple(text,width))
-
-    Example: columnWrite( "Some text", 10, "Next column", 20 )
-    """
-    colWidth = list(islice(cols, 1, None, 2))
-    for line in map(lambda x: izip_longest(colWidth, x), columnMatrix(*cols)):
-        for width, s in line:
-            cl_overriding.printSUCCESS(("{0:%d} " % (width or 1)).format(s),
-                                       printBR=False)
-        cl_overriding.printSUCCESS("", printBR=True)
-
-
 def justify(s, width):
     """
     Выровнить текст по ширине
@@ -192,17 +175,17 @@ class tableReport(object):
                 columnsWidth.append(0)
         # Вычисляем ширину столбцов
         for e in self.dataList:
-            i = 0
-            for s in e:
-                lenS = len(_u(s))
+            for i, s in enumerate(e):
+                lenS = len(_u(s))+1
                 if columnsWidth[i] < lenS:
                     columnsWidth[i] = lenS
-                i += 1
         return columnsWidth
 
-    def createFormatStr(self, listStr):
+    def createFormatStr(self, listStr, offset=0):
         """Создает список (текст, ширина ...)"""
-        return chain(*izip_longest(listStr, self.columnsWidth, fillvalue=""))
+        return chain(*izip_longest(listStr,
+                                   map(lambda x:x-offset, self.columnsWidth),
+                                   fillvalue=""))
 
     def printFunc(self, s):
         """
@@ -246,7 +229,7 @@ class tableReport(object):
                       columnMatrix(*self.createFormatStr(listStrSep))]]
         for s in self.dataList:
             printData.append([self.vertChar, self.body_printer,
-                              columnMatrix(*self.createFormatStr(s))])
+                              columnMatrix(*self.createFormatStr(s, 1))])
         printData.append([self.crossChar, self.line_printer,
                           columnMatrix(*self.createFormatStr(listStrSep))])
         last_col = len(self.headerList) - 1
@@ -254,10 +237,17 @@ class tableReport(object):
         for char, _print, row in printData:
             for line in row:
                 self.line_printer(char[self.colSpan:])
-                for i, align, width, txt in izip(count(), self.align,
-                                                 self.columnsWidth,
-                                                 line):
-                    _print((u"{0:%s%d}" % (align, width)).format(txt))
+                for i, width, txt in izip(count(),
+                                          self.columnsWidth, line):
+                    if _print == self.body_printer:
+                        align = "<"
+                        offset = " "
+                        if width:
+                            width -= 1
+                    else:
+                        align = "^"
+                        offset = ""
+                    _print((u"%s{0:%s%d}" % (offset, align, width)).format(txt))
                     if i < last_col:
                         self.line_printer(char)
                 self.line_printer(char[:-self.colSpan + 1])
